==> pointpos_api-0.0.16.tar.gz: test/modifier_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for ModifierApi
void main() {
  var instance = new ModifierApi();

  group('tests for ModifierApi', () {
    // Create Modifier
    //
    // Create Modifier
    //
    //Future<Modifier> createModifier(String authorization, String xAPIKey, Modifier body, { String xPin }) async 
    test('test createModifier', () async {
      // TODO
    });

    // Delete Modifier By ID
    //
    // Delete Modifier By ID
    //
    //Future deleteModifierByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteModifierByID', () async {
      // TODO
    });

    // Get Modifier List
    //
    // Get Modifier  List
    //
    //Future<List<Modifier>> findModifier(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findModifier', () async {
      // TODO
    });

    // Get Modifier By ID
    //
    // Get Modifier By ID
    //
    //Future<Modifier> getModifierByID(String authorization, String xAPIKey, String id) async 
    test('test getModifierByID', () async {
      // TODO
    });

    // Update Modifier By ID
    //
    // Update [object Object] By ID
    //
    //Future<Modifier> updateModifierByID(String authorization, String xAPIKey, String id, Modifier body, { String xPin }) async 
    test('test updateModifierByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/modifier_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for ModifierApi
void main() {
  var instance = new ModifierApi();

  group('tests for ModifierApi', () {
    // Create Modifier
    //
    // Create Modifier
    //
    //Future<Modifier> createModifier(String authorization, String xAPIKey, Modifier body, { String xPin }) async 
    test('test createModifier', () async {
      // TODO
    });

    // Delete Modifier By ID
    //
    // Delete Modifier By ID
    //
    //Future deleteModifierByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteModifierByID', () async {
      // TODO
    });

    // Get Modifier List
    //
    // Get Modifier  List
    //
    //Future<List<Modifier>> findModifier(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findModifier', () async {
      // TODO
    });

    // Get Modifier By ID
    //
    // Get Modifier By ID
    //
    //Future<Modifier> getModifierByID(String authorization, String xAPIKey, String id) async 
    test('test getModifierByID', () async {
      // TODO
    });

    // Update Modifier By ID
    //
    // Update [object Object] By ID
    //
    //Future<Modifier> updateModifierByID(String authorization, String xAPIKey, String id, Modifier body, { String xPin }) async 
    test('test updateModifierByID', () async {
      // TODO
    });

  });
}
